@@ -72,7 +72,7 @@ All (typescript) examples can be found in the folder [examples](src/examples/).
 
 ## ActionSecret
 
-```typescript
+```python
 import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 import { ActionSecret } from 'cdk-github';
 
@@ -95,7 +95,7 @@ export class ActionSecretStack extends Stack {
 
 ## ActionEnvironmentSecret
 
-```typescript
+```python
 import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 import { ActionEnvironmentSecret } from 'cdk-github';
 
@@ -119,7 +119,7 @@ export class ActionEnvironmentSecretStack extends Stack {
 
 ## GitHubResource
 
-```typescript
+```python
 import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 import { StringParameter } from 'aws-cdk-lib/aws-ssm';
 import { GitHubResource } from 'cdk-github';
@@ -160,6 +160,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_secretsmanager
@@ -200,6 +202,10 @@ class ActionEnvironmentSecret(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ActionEnvironmentSecret.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ActionEnvironmentSecretProps(
             environment=environment,
             github_token_secret=github_token_secret,
@@ -245,6 +251,14 @@ class ActionEnvironmentSecretProps:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ActionEnvironmentSecretProps.__init__)
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
+            check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
+            check_type(argname="argument repository_secret_name", value=repository_secret_name, expected_type=type_hints["repository_secret_name"])
+            check_type(argname="argument source_secret", value=source_secret, expected_type=type_hints["source_secret"])
+            check_type(argname="argument source_secret_json_field", value=source_secret_json_field, expected_type=type_hints["source_secret_json_field"])
         self._values: typing.Dict[str, typing.Any] = {
             "environment": environment,
             "github_token_secret": github_token_secret,
@@ -361,6 +375,10 @@ class ActionSecret(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ActionSecret.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ActionSecretProps(
             github_token_secret=github_token_secret,
             repository=repository,
@@ -402,6 +420,13 @@ class ActionSecretProps:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ActionSecretProps.__init__)
+            check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
+            check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
+            check_type(argname="argument repository_secret_name", value=repository_secret_name, expected_type=type_hints["repository_secret_name"])
+            check_type(argname="argument source_secret", value=source_secret, expected_type=type_hints["source_secret"])
+            check_type(argname="argument source_secret_json_field", value=source_secret_json_field, expected_type=type_hints["source_secret_json_field"])
         self._values: typing.Dict[str, typing.Any] = {
             "github_token_secret": github_token_secret,
             "repository": repository,
@@ -515,6 +540,10 @@ class GitHubResource(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitHubResource.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubResourceProps(
             create_request_endpoint=create_request_endpoint,
             delete_request_endpoint=delete_request_endpoint,
@@ -572,6 +601,17 @@ class GitHubResourceProps:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitHubResourceProps.__init__)
+            check_type(argname="argument create_request_endpoint", value=create_request_endpoint, expected_type=type_hints["create_request_endpoint"])
+            check_type(argname="argument delete_request_endpoint", value=delete_request_endpoint, expected_type=type_hints["delete_request_endpoint"])
+            check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
+            check_type(argname="argument create_request_payload", value=create_request_payload, expected_type=type_hints["create_request_payload"])
+            check_type(argname="argument create_request_result_parameter", value=create_request_result_parameter, expected_type=type_hints["create_request_result_parameter"])
+            check_type(argname="argument delete_request_payload", value=delete_request_payload, expected_type=type_hints["delete_request_payload"])
+            check_type(argname="argument update_request_endpoint", value=update_request_endpoint, expected_type=type_hints["update_request_endpoint"])
+            check_type(argname="argument update_request_payload", value=update_request_payload, expected_type=type_hints["update_request_payload"])
+            check_type(argname="argument write_response_to_ssm_parameter", value=write_response_to_ssm_parameter, expected_type=type_hints["write_response_to_ssm_parameter"])
         self._values: typing.Dict[str, typing.Any] = {
             "create_request_endpoint": create_request_endpoint,
             "delete_request_endpoint": delete_request_endpoint,
@@ -745,7 +785,7 @@ class IGitHubRepository(typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''(experimental) The GitHub repository name.
@@ -758,7 +798,7 @@ class IGitHubRepository(typing_extensions.Protocol):
     def name(self, value: builtins.str) -> None:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> typing.Optional[builtins.str]:
         '''(experimental) The GitHub repository owner.
@@ -781,7 +821,7 @@ class _IGitHubRepositoryProxy:
 
     __jsii_type__: typing.ClassVar[str] = "cdk-github.IGitHubRepository"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''(experimental) The GitHub repository name.
@@ -792,9 +832,12 @@ class _IGitHubRepositoryProxy:
 
     @name.setter
     def name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(IGitHubRepository, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> typing.Optional[builtins.str]:
         '''(experimental) The GitHub repository owner.
@@ -807,6 +850,9 @@ class _IGitHubRepositoryProxy:
 
     @owner.setter
     def owner(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(IGitHubRepository, "owner").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "owner", value)
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
